@@ -99,13 +99,17 @@
 ## @end table
 ##
 ## @strong{Equations}
+## @tex
+## $$\dot{x} = A\,x + B\,u$$
+## $$y = C\,x + D\,u$$
+## @end tex
+## @ifnottex
 ## @example
-## @group
-## .
-## x = A x + B u
-## y = C x + D u
-## @end group
+##   .
+##   x = A x + B u
+##   y = C x + D u
 ## @end example
+## @end ifnottex
 ##
 ## @strong{Example}
 ## @example
@@ -114,41 +118,25 @@
 ## octave:2> b = [10; 11; 12];
 ## octave:3> stname = @{'V', 'A', 'kJ'@};
 ## octave:4> sys = ss (a, b, 'stname', stname)
-## @end group
-## @end example
 ## 
-## @example
-## @group
 ## sys.a =
 ##         V   A  kJ
 ##    V    1   2   3
 ##    A    4   5   6
 ##    kJ   7   8   9
-## @end group
-## @end example
 ## 
-## @example
-## @group
 ## sys.b =
 ##        u1
 ##    V   10
 ##    A   11
 ##    kJ  12
-## @end group
-## @end example
-## 
-## @example
-## @group
+##
 ## sys.c =
 ##         V   A  kJ
 ##    y1   1   0   0
 ##    y2   0   1   0
 ##    y3   0   0   1
-## @end group
-## @end example
 ## 
-## @example
-## @group
 ## sys.d =
 ##        u1
 ##    y1   0
@@ -275,4 +263,4 @@ function G = dss2ss (G)
 
   [G.a, G.b, G.c, G.d, G.e] = __dss2ss__ (G.a, G.b, G.c, G.d, G.e);
 
-endfunction
+endfunction
\ No newline at end of file
